@@ -399,7 +399,7 @@ class Dataset(DatasetMeta):
             raise InvalidParamsError(param_name="storage_type", param_value=storage_type)
 
         if storage_type == "external":
-            CloudClient.get_cloud_storage_config(self._x_api, '', storage_type=storage_type)
+            CloudClient.get_cloud_storage_config(self._x_api, '', storage_type)
 
         self.checkout(self._version)
         export_type = "annotation_uri" if self._annotation_status == 2 else "uri_json_standard"
@@ -407,9 +407,10 @@ class Dataset(DatasetMeta):
         post_data: Dict[str, Any] = {
             "dataset_id": self._id if not dataset_ids else dataset_ids,
             "export_type": export_type,
-            "storage_type": storage_type,
             "task_type": "shared_links",
         }
+        if export_type == "annotation_uri":
+            post_data["storage_type"] = storage_type
         if export_path:
             if isinstance(export_path, list):
                 # path = [self._x_api.get_dataset_path(self._id, path) for path in export_path]
